//Http配置
import Axios from 'axios'
import {
    ElMessage
} from 'element-plus'
import router from "../../router"
import TokenManager from "./token"

// Axios.defaults.timeout = 10000; // 超时时间
Axios.defaults.headers['verify'] = 'omp'; // 验证

/**
 * 拦截http请求
 */
Axios.interceptors.request.use(config => {
    // 判断是否存在token，如果存在的话，则每个http header都加上token
    try {
        const obj = JSON.parse(TokenManager.getToken());
        config.headers['token'] = obj.token;
    } catch {
        return config;
    }
    return config;
});


/**
 * 拦截http响应
 */
Axios.interceptors.response.use(res => {
    switch (res.data.status) { //状态码
        case 200:
            return Promise.resolve(res.data);
        case 300: //警告
            ElMessage.error(res.data.msg);
            break;
        case 401: //权限不足
            ElMessage.error("请先登录");
            router.replace("/login");
            break;
        case 500: //服务器错误
            ElMessage.error("服务器开小差了");
            break;
        default://无状态码
            ElMessage.error("请求状态异常");
            break;
    }
    return Promise.reject(res.data);
}, error => {
    ElMessage.error("请求异常");
    return Promise.reject(error);
});

export default Axios
